@@ -4,22 +4,24 @@
 ### code chunk number 1: init
 ###################################################
 options(prompt = "R> ", continue = "+  ", width = 76, useFancyQuotes = FALSE)
-repos <- "http://cran.at.r-project.org"
+
 ## check if a current version of gamboostLSS is installed
 suppressWarnings(pd <- packageDescription("gamboostLSS"))
 if (all(is.na(pd))){
-    install.packages("gamboostLSS", repos = repos)
-    pd <- packageDescription("gamboostLSS")
+    stop(sQuote("gamboostLSS"), "not properly installed.")
 } else {
     if (compareVersion(pd$Version, "1.2-0") < 0){
-        warning(sQuote("gamboostLSS"), " (1.2-0 or newer) is being installed!")
-        install.packages("gamboostLSS", repos = repos)
+        stop(sQuote("gamboostLSS"), " (1.2-0 or newer) needs to be installed!")
     }
 }
 
 ## for the exact reproduction of the plots R2BayesX >= 0.3.2 is needed
-suppressWarnings(if (!require("R2BayesX"))
-                     install.packages("R2BayesX", repos = repos))
+if (!require("R2BayesX"))
+  stop("cannot attach package ", sQuote("R2BayesX"))
+
+if (!require("BayesX"))
+  stop("cannot attach package ", sQuote("BayesX"))
+
 
 ## remove (possibly) altered versions of "india" from working environment
 suppressWarnings(rm("india"))
@@ -78,14 +80,14 @@ plot(lmLSS, off2int = TRUE)
 
 
 ###################################################
-### code chunk number 8: gamboostLSS_Tutorial.Rnw:308-310
+### code chunk number 8: gamboostLSS_Tutorial.Rnw:309-311
 ###################################################
 muFit <- fitted(lmLSS, parameter = "mu")
 rbind(muFit, truth = 1 + 2 * x1 - x2)[, 1:5]
 
 
 ###################################################
-### code chunk number 9: gamboostLSS_Tutorial.Rnw:315-317
+### code chunk number 9: gamboostLSS_Tutorial.Rnw:316-318
 ###################################################
 sigmaFit <- fitted(lmLSS, parameter = "sigma", type = "response")[, 1]
 rbind(sigmaFit, truth = exp(0.5 - 0.25 * x1 + 0.5 * x3))[, 1:5]
@@ -102,32 +104,35 @@ names(india)
 ###################################################
 ### code chunk number 11: india_stunting1
 ###################################################
-library("R2BayesX")
-## plot mean
-FUN <- mean
-india_agg <- data.frame(mcdist = names(tapply(india$stunting, india$mcdist, FUN,
-                                              na.rm = TRUE)),
-                        stunting = tapply(india$stunting, india$mcdist, FUN,
-                                          na.rm = TRUE))
-par(mar = c(1, 0, 2, 0))
-plotmap(india.bnd, india_agg, pos = "bottomright",
-        range = c(-5.1, 1.50), main = "Mean", mar.min = NULL)
+if (require("R2BayesX")) {
+  ## plot mean
+  FUN <- mean
+  india_agg <- data.frame(mcdist = names(tapply(india$stunting, india$mcdist, FUN,
+                                                na.rm = TRUE)),
+                          stunting = tapply(india$stunting, india$mcdist, FUN,
+                                            na.rm = TRUE))
+  par(mar = c(1, 0, 2, 0))
+  plotmap(india.bnd, india_agg, pos = "bottomright",
+          range = c(-5.1, 1.50), main = "Mean", mar.min = NULL)
+}
 
 
 ###################################################
 ### code chunk number 12: india_stunting2
 ###################################################
-## plot sd
-FUN <- sd
-india_agg <- data.frame(mcdist = names(tapply(india$stunting, india$mcdist, FUN,
-                                              na.rm = TRUE)),
-                        stunting = tapply(india$stunting, india$mcdist, FUN,
-                                          na.rm = TRUE))
-## remove missing values (= no variation)
-india_agg <- india_agg[complete.cases(india_agg),]
-par(mar = c(1, 0, 2, 0))
-plotmap(india.bnd, india_agg, pos = "bottomright",
-        range = c(0, 4.00), main = "Standard deviation")
+if (require("R2BayesX")) {
+  ## plot sd
+  FUN <- sd
+  india_agg <- data.frame(mcdist = names(tapply(india$stunting, india$mcdist, FUN,
+                                                na.rm = TRUE)),
+                          stunting = tapply(india$stunting, india$mcdist, FUN,
+                                            na.rm = TRUE))
+  ## remove missing values (= no variation)
+  india_agg <- india_agg[complete.cases(india_agg),]
+  par(mar = c(1, 0, 2, 0))
+  plotmap(india.bnd, india_agg, pos = "bottomright",
+          range = c(0, 4.00), main = "Standard deviation")
+}
 
 
 ###################################################
@@ -237,28 +242,28 @@ writeLines(out)
 
 
 ###################################################
-### code chunk number 23: gamboostLSS_Tutorial.Rnw:908-910
+### code chunk number 23: gamboostLSS_Tutorial.Rnw:912-914
 ###################################################
 emp_risk <- risk(mod, merge = TRUE)
 tail(emp_risk, n = 1)
 
 
 ###################################################
-### code chunk number 24: gamboostLSS_Tutorial.Rnw:913-915
+### code chunk number 24: gamboostLSS_Tutorial.Rnw:917-919
 ###################################################
 emp_risk_nonstab <- risk(mod_nonstab, merge = TRUE)
 tail(emp_risk_nonstab, n = 1)
 
 
 ###################################################
-### code chunk number 25: gamboostLSS_Tutorial.Rnw:927-929
+### code chunk number 25: gamboostLSS_Tutorial.Rnw:931-933
 ###################################################
 weights <- sample(c(rep(1, 2000), rep(0, 2000)))
 mod_subset <- update(mod, weights = weights, risk = "oobag")
 
 
 ###################################################
-### code chunk number 26: gamboostLSS_Tutorial.Rnw:932-940 (eval = FALSE)
+### code chunk number 26: gamboostLSS_Tutorial.Rnw:936-944 (eval = FALSE)
 ###################################################
 ## mod_subset <- gamboostLSS(stunting ~ bbs(mage) + bbs(mbmi) +
 ##                      bbs(cage) + bbs(cbmi) +
@@ -271,14 +276,14 @@ mod_subset <- update(mod, weights = weights, risk = "oobag")
 
 
 ###################################################
-### code chunk number 27: gamboostLSS_Tutorial.Rnw:943-945
+### code chunk number 27: gamboostLSS_Tutorial.Rnw:947-949
 ###################################################
 mod_nonstab_subset <- update(mod_nonstab,
                              weights = weights, risk = "oobag")
 
 
 ###################################################
-### code chunk number 28: gamboostLSS_Tutorial.Rnw:949-951
+### code chunk number 28: gamboostLSS_Tutorial.Rnw:953-955
 ###################################################
 tail(risk(mod_subset, merge = TRUE), 1)
 tail(risk(mod_nonstab_subset, merge = TRUE), 1)
